@@ -19,6 +19,8 @@ export class PeeringResponseDto extends ResponseDto {
         this.links = [
             {type: UrlReferenceType.Link, url: `${this.resourceUrl}/groups`},
             {type: UrlReferenceType.Link, url: `${this.resourceUrl}/groups/servers`},
+            {type: UrlReferenceType.Link, url: `${this.resourceUrl}/groups/inbound-rules`},
+            {type: UrlReferenceType.Link, url: `${this.resourceUrl}/groups/rules`},
         ]
     }
-}
\ No newline at end of file
+}
