@@ -7,10 +7,13 @@ import {PeeringGroupServerService} from './peering-group-server.service'
 import {PeeringGroupServerMariadbRepository} from './repositories/peering-group-server.mariadb.repository'
 import {PeeringGroupServerRedisRepository} from './repositories/peering-group-server.redis.repository'
 
+import {TaskAgentModule} from '~/helpers/task-agent.module'
+
 @Module({
     imports: [
         JournalModule,
         forwardRef(() => ExpandModule),
+        forwardRef(() => TaskAgentModule),
     ],
     controllers: [PeeringGroupServerController],
     providers: [
